from django.apps import AppConfig


class WagtailFilterPersistenceConfig(AppConfig):
    name = 'wagtail_filter_persistence'
    label = 'wagtail_filter_persistence'
    verbose_name = "Wagtail Filter Persistence"